"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const Conf = require("conf");
const os = require("os");
class ConfCommand extends command_1.Command {
    async run() {
        const { args, flags } = this.parse(ConfCommand);
        const opts = Object.assign({ projectName: flags.project ? flags.project : this.config.name }, (flags.name && { configName: flags.name }), (flags.cwd && { cwd: flags.cwd }));
        const config = new Conf(opts);
        const key = args.key || flags.key;
        let value = args.value || flags.value;
        if (key) {
            if (flags.delete) {
                config.delete(key);
            }
            else if (value) {
                config.set(key, value);
            }
            else {
                value = config.get(key);
                if (value !== null && value !== undefined) {
                    this.print(value);
                }
            }
        }
        else {
            for (let c of config) {
                this.print(c[0] + os.EOL);
            }
        }
    }
    print(value) {
        if (typeof value === 'object') {
            value = JSON.stringify(value);
        }
        process.stdout.write(value);
    }
}
ConfCommand.description = 'manage configuration';
ConfCommand.flags = {
    help: command_1.flags.help({ char: 'h' }),
    key: command_1.flags.string({ char: 'k', description: 'key of the config' }),
    value: command_1.flags.string({ char: 'v', description: 'value of the config' }),
    delete: command_1.flags.boolean({ char: 'd', description: 'delete?' }),
    project: command_1.flags.string({ char: 'p', description: 'project name' }),
    name: command_1.flags.string({ char: 'n', description: 'config file name' }),
    cwd: command_1.flags.string({ char: 'd', description: 'config file location' }),
};
ConfCommand.args = [
    { name: 'key', description: 'key of the config' },
    { name: 'value', description: 'value of the config' }
];
exports.default = ConfCommand;
